Insert a markdown block These functions will add template chunks into your .Rmd file. A markdown block will be display as a frame with a title in a different background. There are 3 types of blocks: "block", "exampleblock" and "alertblock".
Source: R/addins.R
blocks.RdInsert a markdown block
These functions will add template chunks into your .Rmd file.
A markdown block will be display as a frame with a title in a different
background.
There are 3 types of blocks: "block", "exampleblock" and "alertblock".