Create a template for an INBOmd bookdown report
Arguments
- path
The folder in which to create the folder containing the report. Defaults to the current working directory.
- shortname
The name of the report project. The location of the folder
shortnamedepends on the content ofpath. Whenpathis a subfolder of a git repository, it is changed to the root of that git repository. Whenpathis achecklist::checklistproject, you will find the new report atpath/source/shortname. Whenpathis achecklist::checklistpackage, you will find the new report atpath/inst/shortname. Otherwise you will find the new report atpath/shortname.