Render the report into a zip file for the INBO website
Arguments
- path
The path to the directory where the report is located
See also
Other utils:
add_author(),
add_report_numbers(),
check_dependencies(),
column_start(),
column_width(),
cover_info(),
create_report(),
dyn_table(),
prepare_cover(),
references(),
render_natbib(),
validate_doi()