Create a minutes of a meeting with the INBO corporate identity
Arguments
- present
names of all persons who attended the meeting
- absent
names of all persons who couldn't make it
- chair
chair of the meeting
- floatbarrier
where to place automatic float barriers.
- includes
Named list of additional content to include within the document (typically created using the
includesfunction).- codesize
relative font size for code
- lang
main language
- keep_tex
Keep the intermediate tex file used in the conversion to PDF. Note that this argument does not control whether to keep the auxiliary files (e.g.,
.aux) generated by LaTeX when compiling.texto.pdf. To keep these files, you may setoptions(tinytex.clean = FALSE).- fig_crop
Whether to crop PDF figures with the command
pdfcrop. This requires the toolspdfcropandghostscriptto be installed. By default,fig_crop = TRUEif these two tools are available.- pandoc_args
Additional command line options to pass to pandoc
- ...
extra parameters: see details
See also
Other output:
epub_book(),
gitbook(),
handouts(),
mission(),
pdf_report(),
poster(),
slides()