Create a mission report with the INBO corporate identity
Usage
mission(
conference,
conferencedate,
conferenceplace,
website = "",
reportdate,
colleagues = "",
floatbarrier = c(NA, "section", "subsection", "subsubsection"),
includes = NULL,
codesize = c("footnotesize", "scriptsize", "tiny", "small", "normalsize"),
lang = "dutch",
keep_tex = FALSE,
fig_crop = TRUE,
pandoc_args = NULL,
...
)Arguments
- conference
the name of the conference or workshop
- conferencedate
the date of the conference
- conferenceplace
the location of the conference
- website
the website of the conference
- reportdate
the date of this report
- colleagues
name of other colleagues attending the same conference
- floatbarrier
where to place automatic float barriers.
- includes
Named list of additional content to include within the document (typically created using the
includesfunction).- codesize
relative font size for code
- lang
main language
- keep_tex
Keep the intermediate tex file used in the conversion to PDF. Note that this argument does not control whether to keep the auxiliary files (e.g.,
.aux) generated by LaTeX when compiling.texto.pdf. To keep these files, you may setoptions(tinytex.clean = FALSE).- fig_crop
Whether to crop PDF figures with the command
pdfcrop. This requires the toolspdfcropandghostscriptto be installed. By default,fig_crop = TRUEif these two tools are available.- pandoc_args
Additional command line options to pass to pandoc
- ...
extra parameters: see details
See also
Other output:
epub_book(),
gitbook(),
handouts(),
minutes(),
pdf_report(),
poster(),
slides()